% this script estimates parameters for a monthly 3 parameter Weibull distribution,
% which is a proposed model for Hs, using the method of moments. Area under
% investigation is Haltbanken

clc
clear
close all

years = years();
nr_of_years = 58;
months = zeros(1,12);
% sorting all data into 12 months
for i = 1:nr_of_years
    for j = 1:12
        for k = 1:250
            tmp_col = months(:,j);
            tmp_col(tmp_col == 0) = [];
            length_col = length(tmp_col);
            start = length_col + 1;
            if years(k,j,i) == 0
            else
                months(start,j) = years(k,j,i);
                start = start + 1;
            end
        end
    end
end

% verification that all data is handled
sum_data = 0;
for i = 1:12
    for j = 1:length(months)
        if months(j,i) == 0
        else
            sum_data = sum_data + 1;
        end
    end
end
if sum_data == 166053
    disp('All data has been handled')
end

% determining mean of each month
sum = zeros(1,12);
nr_hs = zeros(1,12);
for i = 1:12
    for j = 1:length(months)
        if months(j,i) == 0
        else
            sum(i) = sum(i) + months(j,i);
            nr_hs(i) = nr_hs(i) + 1;
        end
    end
end
mean = sum./nr_hs;

% determining variance and skewness of each month
sum_var = zeros(1,12);
sum_skew = zeros(1,12);
for i = 1:12
    for j = 1:length(months)
        if months(j,i) == 0
        else
            sum_var(i) = sum_var(i) + (months(j,i) - mean(i))^2 ;
            sum_skew(i) = sum_skew(i) + (months(j,i) - mean(i))^3 ;
        end
    end
end

variance = sum_var./nr_hs;
skewness = (sum_skew./nr_hs)./(variance.^(3/2));

% determining beta from expression of skewness
beta = 1:0.00001:1.5; nom = zeros(1,length(beta));
denom = zeros(1,length(beta)); gamma1 = zeros(1,length(beta));
for i = 1:length(beta)
    nom(i) = gamma(1 + (3/beta(i))) - (3*gamma(1+(1/beta(i)))*gamma(1+(2/beta(i)))) + (2*(gamma(1+(1/beta(i))))^3) ;
    denom(i) = (gamma(1+(2/beta(i))) - (gamma(1+(1/beta(i))))^2)^(3/2) ;
    
    gamma1(i) = nom(i)/denom(i);
    % rounding to 4 digits
    num_dig = 4;
    gamma1(i) = round(gamma1(i)*(10^num_dig))/(10^num_dig);
end

beta_hat = zeros(1,12);
count = 0;
for i = 1:length(skewness)
    % rounding to 4 digits
    num_dig = 4;
    skewness(i) = round(skewness(i)*(10^num_dig))/(10^num_dig);
    
    for j = 1:length(gamma1)
        if count == 1
        else
            if skewness(i) == gamma1(j)
                beta_hat(i) = beta(j);
                count = count + 1;
            end
        end
    end
    count = 0;
end

% with beta_hat established, alpha and lambda can be established 
rho_hat = zeros(1,12);
lambda_hat = zeros(1,12);
for i = 1:12
    rho_hat(i) = sqrt( variance(i)/ ( gamma(1+(2/beta_hat(i))) - (gamma(1+(1/beta_hat(i))))^2 ) ) ;
    lambda_hat(i) = mean(i) - (rho_hat(i)*gamma(1 + (1/beta_hat(i))));
    % rounding 
    rho_hat(i) = round(rho_hat(i)*(10^num_dig))/(10^num_dig);
    lambda_hat(i) = round(lambda_hat(i)*(10^num_dig))/(10^num_dig);
end

start = zeros(1,12);
x = zeros(length(0:0.01:13),12);
for i = 1:12;
    start(i) = lambda_hat(i)+0.1;
    for j = 1:length(x)
        if j == 1
            x(j,i) = start(i);
        else
            x(j,i) = x(j-1,i) + 0.01;
        end
    end
end

wei3_pdf = zeros(length(x),12);
for i = 1:12
    for j = 1:length(x)
        wei3_pdf(j,i) = (beta_hat(i)/rho_hat(i)) * (((x(j)-lambda_hat(i))/(rho_hat(i)))^(beta_hat(i)-1)) * exp(-(((x(j)-lambda_hat(i))/rho_hat(i))^beta_hat(i))) ;
    end
end

figure()
plot(beta,gamma1,'-r')
hold on
for j=1:12
    plot([beta_hat(j),beta_hat(j)],[1, 2.5],'-k')
    hold on
end
axis([1 1.5 1 2.1])
grid on
xlabel('\beta','Fontsize',18);ylabel('Skewness, \gamma_1','Fontsize',18);
h_legend=legend('\gamma_1, using a range of \beta','\gamma_1 calculated from sample');
set(h_legend,'FontSize',14);
width=15.875;
height=0.7*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','mom_est_beta_halten.pdf')


figure()
for j=1:12
    plot(x(:,j),wei3_pdf(:,j))
    
    hold on
end
hold on
axis([0 15 0 0.63])
grid on
xlabel('h_s','Fontsize',18);ylabel('f_{Hs}','Fontsize',18);
Legend=cell(12,1);
for i=1:12
Legend{i}=strcat('Month nr.', num2str(i));
end
legend(Legend,'Fontsize',13)
width=15.875;
height=0.7*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','mom_est_wei_halten.pdf')

% probability paper for one of the months, July
% creating a diagram for various data:
n=length(months(:,7));
dia=zeros(n,4);
dia(:,1)=sort(months(:,7)); % assigning hs-values to column nr. 1 and sorting them
dia(:,2)=log(dia(:,1)); % taking log to hs values, column 2
dia(:,3)=(1:n)./(n+1); % cumulative distribution of Hs, F_Hs, column 3
dia(:,4)=log(-log(1-dia(:,3))); % F_Hs on a Weibull scale, column 4

% removing repeating values
k=1;
for i=2:n
    if dia(i,1) == dia(i-1,1) 
        rm(k)=i-1; % an array which tells us which values we are to exclude
        k=k+1;
    end
end
dia(rm,:)=[]; % removing repeating values

tmp_col = dia(:,1);
tmp_col(tmp_col <= lambda_hat(7)) = [];

wei3_cdf_july = 1 - exp(-((tmp_col-lambda_hat(7))./rho_hat(7)).^beta_hat(7));
y2 = log(-log(1-wei3_cdf_july));

figure()
plot(dia(:,1),dia(:,3),'.k',tmp_col,wei3_cdf_july,'-r')

figure()
plot(dia(:,2),dia(:,4),'.k',log(tmp_col),y2,'-r')
grid on
xlabel('ln(h_s)','Fontsize',18);ylabel('ln(-ln(1-F))','Fontsize',18);
h_legend=legend('Observations','3 parameter Weibull fit','Location','northwest');
set(h_legend,'FontSize',14);
width=15.875;
height=0.7*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','3par_wei_prob_halten.pdf')

% q probabilities
q_ULS=0.01;q_ALS=0.0001;q_01=0.1;q_063=0.63;
% extreme values of Hs (monthly)
ex_table = zeros(4,12);
ex_table(1,:)=rho_hat.*(-log(q_ULS./2920)).^(1./beta_hat)+lambda_hat;
ex_table(2,:)=rho_hat.*(-log(q_ALS./2920)).^(1./beta_hat)+lambda_hat;
ex_table(3,:)=rho_hat.*(-log(q_01./2920)).^(1./beta_hat)+lambda_hat;
ex_table(4,:)=rho_hat.*(-log(q_063./2920)).^(1./beta_hat)+lambda_hat;

% estimating parameters for the entire collection of hs
fid = fopen('Heidrun_WAM10_6529N_0732E.txt','r');
A = fscanf(fid,'%f %f %f %f %*f %*f %f %*f %*f %*f %*f %*f %*f %*f %*f %*f %*f',[5,inf])';
fclose(fid);

hs = A(:,5);
n = length(hs);
sum_mean = 0;
sum_var = 0;
sum_skew = 0;
for i = 1:n
    sum_mean = sum_mean + hs(i);
end

mean_hs = sum_mean/n;

for i = 1:n
    sum_var = sum_var + (hs(i)-mean_hs)^2;
    sum_skew = sum_skew + (hs(i)-mean_hs)^3;
end

var_hs = sum_var/n;
skew_hs = (sum_skew/n)/(sqrt(var_hs))^3;

% determining beta from expression of skewness
beta = 1.2:0.00001:1.3;
for i = 1:length(beta)
    nom(i) = gamma(1 + (3/beta(i))) - (3*gamma(1+(1/beta(i)))*gamma(1+(2/beta(i)))) + (2*(gamma(1+(1/beta(i))))^3) ;
    denom(i) = (gamma(1+(2/beta(i))) - (gamma(1+(1/beta(i))))^2)^(3/2) ;
    
    gamma1(i) = nom(i)/denom(i);
    % rounding to 4 digits
    num_dig = 4;
    gamma1(i) = round(gamma1(i)*(10^num_dig))/(10^num_dig);
end

count = 0;
skew_hs = round(skew_hs*(10^num_dig))/(10^num_dig);
for i = 1:length(gamma1)
    gamma1(i) = round(gamma1(i)*(10^num_dig))/(10^num_dig);
    if count == 1
    else
        if gamma1(i) == skew_hs
            beta_hat_all = beta(i);
            count = count + 1;
        end
    end
end

% with beta_hat established, alpha and lambda can be established 
rho_hat_all = sqrt( var_hs/ ( gamma(1+(2/beta_hat_all)) - (gamma(1+(1/beta_hat_all)))^2 ) ) ;
lambda_hat_all = mean_hs - (rho_hat_all*gamma(1 + (1/beta_hat_all)));

% extreme values of Hs (yearly)
ex_table_all = zeros(4,1);
ex_table_all(1,1)=rho_hat_all*(-log(q_ULS/2920))^(1/beta_hat_all)+lambda_hat_all;
ex_table_all(2,1)=rho_hat_all*(-log(q_ALS/2920))^(1/beta_hat_all)+lambda_hat_all;
ex_table_all(3,1)=rho_hat_all*(-log(q_01/2920))^(1/beta_hat_all)+lambda_hat_all;
ex_table_all(4,1)=rho_hat_all*(-log(q_063/2920))^(1/beta_hat_all)+lambda_hat_all;

  


