% CONTOUR LINES for HALTENBANKEN

global hs tp beta rho alpha theta eta q_ULS q_ALS coeff_mu coeff_var

p=[1-q_ULS/2920, 1-q_ALS/2920];
r=norminv(p,0,1); % determining radius corresponding to values of q
n=1001;
dcircle=2*pi/(n-1);

for j=1:length(p)
    for i=1:n
        circle=dcircle*(i-1);
        U_1(i)=r(j)*cos(circle);
        U_2(i)=r(j)*sin(circle);
        Hs(i,j)=rho*(-log(1-normcdf(U_1(i)))).^(1/beta); %
        
        if Hs(i)>=eta
            contour_Hs(i,j)=Hs(i,j);
        else
            contour_Hs(i,j)=exp(theta+alpha*U_1(i));
        end
        
        mu(i,j)=coeff_mu(1)+coeff_mu(2)*contour_Hs(i,j)^coeff_mu(3);
        sigma(i,j)=coeff_var(1)+coeff_var(2)*exp(-coeff_var(3)*contour_Hs(i,j));
        contour_Tp(i,j)=exp(sqrt(sigma(i,j))*U_2(i)+mu(i,j));
    end
end

% gaussian plot
figure();
grid on
plot(U_1,U_2,'-r',[0 U_1(120)],[0 U_2(120)],'-k',[-max(U_1) max(U_1)],[0 0],'--k',[0,0],[-max(U_1),max(U_1)],'--k')
xlabel('U_1','FontSize',15);ylabel('U_2','FontSize',15)
h_legend = legend('Gaussian contour');
set(h_legend,'FontSize',14);
text(2,1.2,'r = 4.5','Fontsize',18);
width=15.875;
height=0.9*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','uspace.pdf')

% bell curve, explaining probabilities
figure()
xg = -5:0.01:5;
mu = 0;
sigma = 1;
gauss = (1/(sigma*sqrt(2*pi))) .* exp(-(((xg-mu).^2)./(2*sigma^2)));
plot(xg,gauss,[4.5 4.5],[0 0.4],'-k')
hold on
area(xg(1:951),gauss(1:951))
xlabel('x','FontSize',14);ylabel('f(x|\mu=0,\sigma=1)','FontSize',14)
text(-4.9,0.33,'F(x|\mu,\sigma) =0.9999965','Fontsize',14);
text(3,0.3,'x = 4.5','Fontsize',14);
text(-4.2,0.3,'\mu=0, \sigma=1','Fontsize',14);
width=15.875;
height=0.7*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','uprob.pdf')

% contour plot
figure();
plot(contour_Tp(:,1),contour_Hs(:,1),'b',contour_Tp(:,2),contour_Hs(:,2),'r',tp,hs,'.k');
axis([0 40 0 27])
grid on
h_legend = legend('100 year contour','10 000 year contour','Data points');
set(h_legend,'FontSize',14);
xlabel('T_p','FontSize',14);ylabel('H_s','FontSize',14);
width=15.875;
height=0.9*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','contour_halten.pdf')
