% JPDF OF Hs AND Tp

global theta alpha beta rho eta coeff_mu coeff_var

% lower part of hybrid distribution lonowe
f_hs_lower = @(hs) exp(-(log(hs)-theta).^2/(2*alpha^2))./(hs*sqrt(2*pi)*alpha);
% upper part
f_hs_upper = @(hs) beta/rho*(hs/rho).^(beta-1).*exp(-(hs/rho).^beta);
% exptected value mu in lognormal distribution
logn_mu = @(hs) coeff_mu(1)+coeff_mu(2).*hs.^coeff_mu(3);
% variance sigma^2 in lognormal distribution
logn_var = @(hs) coeff_var(1)+coeff_var(2).*exp(-hs.*coeff_var(3));
% lognormal ditribution
f_tp = @(hs,tp) 1./(tp.*sqrt(2*pi*logn_var(hs))).*exp(-(log(tp)-logn_mu(hs)).^2./(2.*logn_var(hs)));

% joint probability distribution function, lower
jpdf_lower=@(hs,tp) f_hs_lower(hs).*f_tp(hs,tp);
% joint probability distribution function, upper
jpdf_upper=@(hs,tp) f_hs_upper(hs).*f_tp(hs,tp);

dx=0.2;
for i=1:10/dx
    hsi(i)=(i-1)*dx;
    for j=1:20/dx
        tpj(j)=(j-1)*dx;
        if hsi(i)<=eta
            f(i,j)=jpdf_lower(hsi(i),tpj(j));
        else
            f(i,j)=jpdf_upper(hsi(i),tpj(j));x
        end
    end
end

figure();
surf(tpj,hsi,f);
colormap cool
xlabel('T_p [s]','FontSize',15)
ylabel('H_s [m]','FontSize',15)
zlabel('f_{H_s,T_p}(h_s,t_p)','FontSize',15)
width=15.875;
height=1*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','jpdf.pdf')




