% ESTABLISHING PARAMETERS OF LOGNORMAL DISTRIBUTION

global hs tp n_obs coeff_mu coeff_var Hs_ULS Hs_ALS Hs_q01 Hs_q063 

n_obs=length(hs); % number of observations
hs_sorted = sort(hs);  % sorting significant wave heights

% ESTIMATION OF MEAN AND VARIANCE IN LOG-TP DISTRIBUTION
k=zeros(1,ceil(hs_sorted(end)));
mu=zeros(1,ceil(hs_sorted(end))); 
variance=zeros(1,ceil(hs_sorted(end)));
hs_mu=0.5:1:ceil(hs_sorted(end));
% taking sum of all periods in each hs interval
for i=1:n_obs
mu(ceil(hs(i)))=mu(ceil(hs(i)))+log(tp(i)); % sum of log tp's in hs interval 'i'
k(ceil(hs(i)))=k(ceil(hs(i)))+1; % number of periods in each hs interval
end
% calculating mean by dividing by number of periods in each hs interval
mu=mu./k;

% calculating variance in each hs interval
for i=1:n_obs
variance(ceil(hs(i)))=variance(ceil(hs(i)))+1/(k(ceil(hs(i))))*(log(tp(i))-mu(ceil(hs(i))))^2;
end

hs_mu(isnan(mu)) = [];
variance(isnan(mu)) = [];
mu(isnan(mu)) = [];

% fitting a curve to mu 
% starting values found in Statoil's metocean report
s=fitoptions('Method','NonlinearLeastSquares','startpoint',[1.71 0.35 0.41]); 
mu_eq=fittype('a1+a2*x^a3','options',s);
mu_fit=fit(hs_mu',mu',mu_eq);
coeff_mu=coeffvalues(mu_fit);

% removing rows of zero variance
ix=find(not(variance)); 
var=variance;
var(ix)=[];
hs_var=hs_mu;
hs_var(ix)=[];

% fitting a curve to sigma^2(variance)
% starting values found in Statoil's metocean report
p=fitoptions('Method','NonlinearLeastSquares','startpoint',[0.005 0.12 0.31]); 
variance_eq=fittype('b1+b2*exp(-x*b3)','options',p);
variance_fit=fit(hs_var(2:end)',var(2:end)',variance_eq); 
coeff_var=coeffvalues(variance_fit);

% caulcalting 95% confidence band for Tp given Hs, using inverse of the CDF
% of lognormal
for i=1:length(hs_mu)
    T_upper(i)=logninv(0.975,mu(i),sqrt(variance(i)));
    T_mean(i)=exp(mu(i));
    T_lower(i)=logninv(0.025,mu(i),sqrt(variance(i)));
end

% calculating confidence bands using inverse of the CDF of lognormal
Tp_ULS=[exp(mu_fit(Hs_ULS)),logninv([0.025 0.975],mu_fit(Hs_ULS),sqrt(variance_fit(Hs_ULS)))];
Tp_ULS_5=[exp(mu_fit(Hs_ULS)),logninv([0.475 0.525],mu_fit(Hs_ULS),sqrt(variance_fit(Hs_ULS)))];
Tp_ULS_50=[exp(mu_fit(Hs_ULS)),logninv([0.25 0.75],mu_fit(Hs_ULS),sqrt(variance_fit(Hs_ULS)))];

Tp_ALS=[exp(mu_fit(Hs_ALS)),logninv([0.05 0.95],mu_fit(Hs_ALS),sqrt(variance_fit(Hs_ALS)))];
Tp_q01=[exp(mu_fit(Hs_q01)),logninv([0.05 0.95],mu_fit(Hs_q01),sqrt(variance_fit(Hs_q01)))];
Tp_q063=[exp(mu_fit(Hs_q063)),logninv([0.05 0.95],mu_fit(Hs_q063),sqrt(variance_fit(Hs_q063)))];

% plotting mu vs. hs
figure();
hold on
grid on
plot(hs_mu,mu,'.k'); 
plot(mu_fit,'-r'); 
grid on
axis([0 17 1.8 2.95])
h_legend=legend('\mu','line fit to \mu','Location','Best');
set(h_legend,'FontSize',13);
xlabel('H_s [m]','FontSize',15);ylabel('\mu','FontSize',15)
width=15.875;
height=0.8*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','mu.pdf')
hold off
hold off

% plotting variance vs. hs
figure();
hold on
plot(hs_mu,variance,'.k');
plot(variance_fit,'-r');
grid on
axis([0 17 0 0.085])
h_legend=legend('\sigma^2','line fit to \sigma^2');
set(h_legend,'FontSize',13);
xlabel('H_s [m]','FontSize',15);ylabel('\sigma^2','FontSize',15);
width=15.875;
height=0.8*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','sigma.pdf')
hold off

% plotting hs versus. tp scatter with confidence band
figure();
hold on
plot(hs, tp, '.k',hs_mu, T_mean,'-b',hs_mu, T_upper, '-r', hs_mu, T_lower, '-r');
grid on
xlabel('H_s [m]','FontSize',15);ylabel('T_p [s]','FontSize',15);
h_legend=legend('Observations','Mean T_p given H_s','95% confidence interval');
set(h_legend,'FontSize',13);
width=15.875;
height=0.8*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','conf.pdf')











