% ESTABLISHING PARAMETERS OF LONOWE DISTRIBUTION

global hs hs_max tp tp_max n_obs theta alpha beta rho eta q_ULS q_ALS Hs_ULS Hs_ALS Hs_q01 Hs_q063 q_01 q_063

% fetching Hs, direction of Hs and Tp from modified Hindcast file
% Heidrun_WAM10_6529N_0732E_modified.txt :
fid = fopen('Heidrun_WAM10_6529N_0732E_mod.txt','r');
A = fscanf(fid,'%f %f %f %f',[4,inf])';
fclose(fid);

n_obs = length(hs);
hs = A(:,2); hs_max = max(hs);
tp = A(:,3); tp_max = max(tp);

% creating a diagram for various data:
dia=zeros(n_obs,5);
dia(:,1)=sort(hs); % assigning hs-values to column nr. 1 and sorting them
dia(:,2)=log(dia(:,1)); % taking log to hs values, column 2
dia(:,3)=(1:n_obs)./(n_obs+1); % cumulative distribution of Hs, F_Hs, column 3
dia(:,4)=log(-log(1-dia(:,3))); % F_Hs on a Weibull scale, column 4
dia(:,5)=erfinv((2*dia(:,3))-1); % F_Hs on a lognormal scale, column 5

% removing repeating values
k=1;
for i=2:n_obs
    if dia(i,1) == dia(i-1,1) 
        rm(k)=i-1; % an array which tells us which values we are to exclude
        k=k+1;
    end
end
dia(rm,:)=[]; % removing repeating values

% ESTIMATING CUT-OFF VALUE ETA
% estimating lognormal paramters using maximum likelihood:
theta=mean(log(hs));
alpha=std(log(hs));

for j=1:100
    eta(j)=dia(1,1)+0.1*j; % starting value of eta, checking for all hs 
    rho(j)=2.803; % starting value of rho
    beta(j)=1.55; % starting value of beta
    % continuity in F and f at eta: 
    flog=exp(-(log(eta(j))-theta).^2/(2*alpha^2))./(eta(j)*sqrt(2*pi)*alpha); 
    Flog=1/2*(1+erf((log(eta(j))-theta)/(alpha*sqrt(2))));
    % determining Weibull paramaters rho and beta via lognormal(continuity)
    for k=1:50;
        rho(j)=eta(j)/(-log(1-Flog))^(1/beta(j)); 
        beta(j)=flog/(1/rho(j)*(eta(j)/rho(j)).^(beta(j)-1).*exp(-(eta(j)/rho(j)).^beta(j)));
    end
    error_est(j)=0;
    for i=1:length(dia(:,1))
        if (dia(i,2))<log(eta(j))
            error=((dia(i,2)-theta)/(sqrt(2)*alpha)-dia(i,5))^2;
        else
            error=((beta(j)*dia(i,2)-beta(j)*log(rho(j)))-dia(i,4))^2; 
        end
        error_est(j)=error_est(j)+ error;
    end
end    

% plotting eta versus error_est, disregarding some very large values
x_data = eta(32:1:length(eta));
y_data = error_est(32:1:length(error_est));

[~, s]=min(error_est); % determining which error is smallest
beta=beta(s); 
rho=rho(s); 
eta=eta(s);

% DETERMINING ULS AND ALS SIGNIFICANT WAVE HEIGHT:
% annual probabilites corresponding to ULS, ALS, 0.1 and 0.63:
q_ULS=0.01;
q_ALS=0.0001;
q_01=0.1;
q_063=0.63;

Hs_ULS=rho*(-log(q_ULS/2920))^(1/beta);
Hs_ALS=rho*(-log(q_ALS/2920))^(1/beta);
Hs_q01=rho*(-log(q_01/2920))^(1/beta);
Hs_q063=rho*(-log(q_063/2920))^(1/beta);

% PROBABILITY PAPERS
% Weibull probability paper
figure()
x=dia(1,2):0.1:log(Hs_ALS)+0.1; % x-axis of Weibull probability paper
y_wei=beta*x-beta*log(rho); % y-axis of Weibull probability paper
plot(dia(:,2),dia(:,4),'.k',[log(eta) log(eta)],[-9.2 4],'b',x,y_wei,'-r') 
grid on
axis([-1.6 3.2 -9.2 3.1])
xlabel('ln(h_s)','FontSize',15);ylabel('ln(-ln(1-F_{H_s}(h_s)))','FontSize',15)
h_legend = legend('Population', '\eta', 'Curve fit(Weibull)','Location','Best');
set(h_legend,'FontSize',13);
width=15.875;
height=0.8*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','wei_lonowe.pdf')

% Lognormal probability paper
figure()
y_logn=(x-theta)/(sqrt(2)*alpha);
plot(dia(:,2),dia(:,5),'.k',[log(eta) log(eta)],[-3 4],'b',x,y_logn,'-r')
grid on
axis([-1.5 3.35 -3 3.5])
xlabel('ln(h_s)','FontSize',15);ylabel('inverf(2F_{H_s}(h_s)-1)','FontSize',15)
h_legend = legend('Population', '\eta', 'Curve fit(Lognormal)','Location','Best');
set(h_legend,'FontSize',13);
width=15.875;
height=0.8*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','logn_lonowe.pdf')
    
% Plotting LoNoWe Distribution
x_lower=0:0.01:eta;
x_upper=eta:0.01:Hs_ALS+0.1;
logn=1/2*(1+erf((log(x_lower)-theta)./(sqrt(2)*alpha))); 
weibull=1-exp(-(x_upper/rho).^beta);
   figure()
grid on
plot(dia(:,1),dia(:,3),'.k',[(eta) (eta)],[0 1],'-r',x_lower,logn,'g',x_upper,weibull,'b');
axis([0 22 0 1])
h_legend = legend('Population','\eta','Lognormal CDF fit','Weibull CDF fit','Location','Best');
set(h_legend,'FontSize',13);
xlabel('H_s [m]','FontSize',15);ylabel('F_{H_s}','FontSize',15);
width=15.875;
height=0.8*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','lonowe.pdf')

    
    
    
    
