% MODIFICATION OF WIND SPEED AND SPECTRAL PEAK PERIOD
% area: Haltenbanken
% This script was only run once during the project, in order to utilize a
% consistent set of data

% fetching wind speed, Hs, Tp and direction from the Hindcast 
% data file: Heidrun_WAM10_6529N_0732E.txt :
fid = fopen('Heidrun_WAM10_6529N_0732E.txt','r');
A = fscanf(fid,'%*f %*f %*f %*f %f %*f %f %f %*f %*f %f %*f %*f %*f %*f %*f %*f',[4,inf])';
fclose(fid);

ws=A(:,1); % wind speed
hs=A(:,2); % significant wave height
tp=A(:,3); % spectral peak period
dir=A(:,4); % wave direction
n_obs=length(hs); % number of observations
hs_max = max(hs); % largest significant wave height
ws_max = max(ws); % largest wind speed
 
% modification of wind speed, increasing the largest wind speeds by
% w_corr=w+0.2*(w-15.)
ws_mod = zeros(n_obs,1);
for i=1:n_obs
    if ws(i) > 15
        ws_mod(i,1)=ws(i)+(0.2*(ws(i)-15)); 
    else
        ws_mod(i,1)=ws(i); 
    end    
end

% modification of spectral peak period, Tp: procedure given in
% 'Memo_WAM10_OJAN_301'
tp_dia = zeros(n_obs,3); % creating a diagram for old and new values
tp_dia(:,1) = tp; 
for i=1:n_obs
    tp_dia(i,2)=round(1+((log(tp(i)/3.244))/0.09525)); % calculating 'i'
    tp_dia(i,3)=3.244*exp(0.09525*(tp_dia(i,2)-0.5-rand(1))); %calculating modified Tp
end
tp_mod=tp_dia(:,3); %assigning modified tp values to a new array
tp_max = max(tp_mod);

A(:,1)=ws_mod;
A(:,3)=tp_mod;

% writing modified values of ws and tp + original hs and directions to file
dlmwrite('Heidrun_WAM10_6529N_0732E_modified.txt',A,'delimiter','\t','precision',3)

figure()
plot(hs,tp,'.k');
grid on
xlabel('H_s [m]','FontSize',16);ylabel('T_p [s]','FontSize',16);
h=legend('Observations');
set(h,'FontSize',15)
width=15.875;
height=1.0*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','no_mod.pdf')

figure()
plot(hs,tp_mod,'.k');
grid on
xlabel('H_s [m]','FontSize',16);ylabel('T_p [s]','FontSize',16);
h=legend('Observations');
set(h,'FontSize',15)
width=15.875;
height=1.0*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','mod.pdf')






