% monthly Lognormal distributions, Haltenbanken

global coeff_mu coeff_var

years = years();
nr_of_years = 58;
months_hs = zeros(1,12);
% sorting all values of hs into months
for i = 1:nr_of_years
    for l = 1:12
        for k = 1:250
            tmp_col = months_hs(:,l);
            tmp_col(tmp_col == 0) = [];
            length_col = length(tmp_col);
            start = length_col + 1;
            if years(k,l,i) == 0
            else
                months_hs(start,l) = years(k,l,i);
                start = start + 1;
            end
        end
    end
end

% verification that all data is handled
sum_data1 = 0;
for i = 1:12
    for l = 1:length(months_hs)
        if months_hs(l,i) == 0
        else
            sum_data1 = sum_data1 + 1;
        end
    end
end
if sum_data1 == 166053
    disp('All Hs values have been handled')
end

% fetching modified tp values
fid = fopen('Heidrun_WAM10_6529N_0732E_mod.txt','r');
A = fscanf(fid,'%*f %f %f %f',[3,inf])';
fclose(fid);
tp = A(:,2);
% fetching other information
fid = fopen('Heidrun_WAM10_6529N_0732E.txt','r');
B = fscanf(fid,'%f %f %f %f %*f %*f %f %*f %*f %*f %*f %*f %*f %*f %*f %*f %*f',[5,inf])';
fclose(fid);
year = B(:,1);
month = B(:,2);

months_tp = zeros(1,12);
% sorting data into months
for i = 1:length(tp)
    tmp_col = months_tp(:,month(i));
    tmp_col(tmp_col == 0) = [];
    if isempty(tmp_col)==1
        k=1;
        months_tp(k,month(i)) = tp(i);
    else
        k = length(tmp_col) + 1;
        months_tp(k,month(i)) = tp(i);
    end
end

% verification that all data is handled
sum_data2 = 0;
for i = 1:12
    for l = 1:length(months_tp)
        if months_tp(l,i) == 0
        else
            sum_data2 = sum_data2 + 1;
        end
    end
end
if sum_data2 == 166053
    disp('All Tp values have been handled')
end

coeff_mu = zeros(3,12);
coeff_var = zeros(3,12);
for j = 1:12
    tmp_col = months_hs(:,j);
    tmp_col(tmp_col == 0) = [];
    hs = tmp_col;
    n_obs=length(tmp_col); % number of observations
    hs_sorted = sort(tmp_col);  % sorting significant wave heights
    
    tmp_col2 = months_tp(:,j);
    tmp_col2(tmp_col2 == 0) = [];
    tp = tmp_col2;
    
    % ESTIMATION OF MEAN AND VARIANCE IN LOG-TP DISTRIBUTION
    k=zeros(1,ceil(hs_sorted(end)));
    mu=zeros(1,ceil(hs_sorted(end))); 
    variance=zeros(1,ceil(hs_sorted(end)));
    hs_mu=0.5:1:ceil(hs_sorted(end));
    % taking sum of all periods in each hs interval
    for i=1:n_obs
        mu(ceil(hs(i)))=mu(ceil(hs(i)))+log(tp(i)); % sum of log tp's in hs interval 'i'
        k(ceil(hs(i)))=k(ceil(hs(i)))+1; % number of periods in each hs interval
    end
    % calculating mean by dividing by number of periods in each hs interval
    mu=mu./k;

    % calculating variance in each hs interval
    for i=1:n_obs
    variance(ceil(hs(i)))=variance(ceil(hs(i)))+1/(k(ceil(hs(i))))*(log(tp(i))-mu(ceil(hs(i))))^2;
    end

    hs_mu(isnan(mu)) = [];
    variance(isnan(mu)) = [];
    mu(isnan(mu)) = [];

    % fitting a curve to mu 
    % starting values found in Statoil's metocean report
    s=fitoptions('Method','NonlinearLeastSquares','startpoint',[1.71 0.35 0.41]); 
    mu_eq=fittype('a1+a2*x^a3','options',s);
    mu_fit=fit(hs_mu',mu',mu_eq);
    coeff_mu(:,j)=coeffvalues(mu_fit);

    % removing rows of zero variance
    ix=find(not(variance)); 
    var=variance;
    var(ix)=[];
    hs_var=hs_mu;
    hs_var(ix)=[];
    
    % fitting a curve to sigma^2(variance)
    % starting values found in Statoil's metocean report
    p=fitoptions('Method','NonlinearLeastSquares','startpoint',[0.005 0.12 0.31]); 
    variance_eq=fittype('b1+b2*exp(-x*b3)','options',p);
    variance_fit=fit(hs_var',var',variance_eq); 
    coeff_var(:,j)=coeffvalues(variance_fit);
    
    % if the parameter b1 is smaller or equal to zero, this has to be
    % changed in order to avoid an expression which yields negative
    % variance
    if coeff_var(1,j) <= 0
        b1 = coeff_var(1,j);
        coeff_var(1,j) = 0.0001;
    end
end
