% this script establishes parameters of a Weibull distribution which
% describes the duration of calms. Area under investigation is Haltenbanken

clear

nr_of_years = 58;
th = 2; % threshold value Hs'

% fetching sorted hindcast data by using function years.m
years = years();

x1 = 5:10:745;
nr_probs = length(x1);
F = zeros(5,nr_probs); % prob_under_t,nr_calms_under_t,tot_nr_calms,tot_nr_hrs,n_plus_1
% establishing CDF's by using the funciton prob_under_t_func.m
for i=1:nr_probs;
    % cumulative probability
    [F(1,i),F(2,i),F(3,i),F(4,i),F(5,i)] = prob_under_t_func(x1(i),2,years);
end

figure()
plot(x1,F(1,:));
grid on

% y and x-axis of probability paper
y = log(-log(1-F(1,:)));
x = log(x1);

% figure()
% plot(x,y);
% grid on

% fitting a curve 
s=fitoptions('Method','NonlinearLeastSquares'); 
eq=fittype('a*x+b','options',s);
fit=fit(x',y',eq);
coeff_y=coeffvalues(fit);

% establishing parameters rho and beta of the 2 par. Weibull dist.
beta = coeff_y(1);
rho = exp(-((coeff_y(2))/(beta)));

x3 = 0:5:800;
x4 = 5:10:745;
% del1 = beta./rho;
% del_del = (beta-1);
% del2 = (x3./rho).^(del_del);
% del3 = exp(-(x3./rho).^(beta)); 
% y2 = del1.*del2.*del3;
y2 = (beta./rho).*(x3./rho).^(beta-1).*exp(-(x3./rho).^beta);
area = trapz(x3,y2);
CDF = 1-(exp(-(x4./rho).^beta));
[pks,loc] = findpeaks(y2);
mean_tau =  rho*gamma(1+(1/beta));

x2 = 0:0.1:6.9;
y1 = coeff_y(1).*x2 + coeff_y(2); 
figure()
plot(x,y,'.k',x2,y1,'-r')
xlabel('ln(t)','Fontsize',15);ylabel('ln(-ln(1-F))','Fontsize',15)
legend('Data','Curve Fit','Location','Northwest','Fontsize',14);
axis([1 7 -5 2.5]);
grid on
width=15.875;
height=0.6*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','calm_fit.pdf')


figure()    
plot(x3,y2,'-k')
xlabel('t [hours]','Fontsize',16);ylabel('f(\tau_c| \rho,\beta)','Fontsize',16);
grid on
axis([0 750 0 0.025])
width=15.875;
height=0.6*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','calms_pdf.pdf')




figure()
plot(x4,CDF,'-k')
xlabel('t [hours]','Fontsize',15);ylabel('P[\tau_c \leq t]','Fontsize',15)
axis([0 750 0 1])
grid on
width=15.875;
height=0.6*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','calms_cdf.pdf')




