% this script estimates parameters of a 2 parameter Weibull distribution for
% the duration of calms. Area: Haltenbanken

clear

% fetching sorted data using function 'years.m'
years = years();
th = 2; % threshold value Hs'

% esitmation of E[tau_c] from data, using function 'prob_under_t_func.m'
[prob_under_t,nr_calms_under_t,tot_nr_calms,tot_nr_hrs,n_plus_1] = prob_under_t_func(15,2,years);
mean_tau_from_data = tot_nr_hrs / tot_nr_calms;

% estimation of VAR[tau_c]:
nr_of_years = 58;
tot_nr_calms = 0;
tot_nr_hrs = 0;
sum_variance = 0;
for i = 1:nr_of_years
    for j = 1:12
        tmp_col = years(:,j,i);
        tmp_col(tmp_col == 0) = [];
        if isempty(tmp_col) == 1
        else
            calms = durationz(tmp_col,th);
            n_rows = length(calms(:,1));
            tot_nr_calms = tot_nr_calms + n_rows;     
               
            for k = 1:n_rows
                tmp_calm = calms(k,:);
                tmp_calm(tmp_calm ==0) = [];

                hrs_in_calm = 3*length(tmp_calm(1,:));
                tot_nr_hrs = tot_nr_hrs + hrs_in_calm;
                
                tmp_calm_squared = (hrs_in_calm - mean_tau_from_data)^2;
                sum_variance = sum_variance + tmp_calm_squared;
            end  
           
        end
    end
end

variance_tau_from_data = sum_variance / tot_nr_calms;
standard_deviance_tau_from_data = sqrt(variance_tau_from_data);

ratio = standard_deviance_tau_from_data / mean_tau_from_data;

beta = 0.65:0.00001:0.9;
for i = 1:length(beta)
    nominator = sqrt( gamma(1 + (2/beta(i))) - (gamma(1 + (1/beta(i))))^2 );
    denominator = gamma(1 + (1/beta(i)));
    a(i) = (nominator/denominator) - ratio;
end

% determnining which number is closest to zero
[c, index] = min(abs(a-0));
% estimator for paramter beta, beta_hat:
beta_hat = beta(index);

figure()
plot(beta,a,'-k',[beta_hat,beta_hat],[-0.2, 0.3],'-b')
xlabel('\beta');
t1 = text(0.78,0.125,'$\hat{\beta}$','Fontsize',14);
set(t1, 'Interpreter', 'latex','color','b')
grid on
width=15.875;
height=0.6*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','mom_est.pdf')

% estimator for parameter rho, rho_hat:
rho_hat = 56.2637895812053/(gamma(1+ (1/beta_hat))); % 56.2637... is calculated in average_duration.m

mean_tau_wei_estimator =  rho_hat*gamma(1+(1/beta_hat));

% plotting new PDF:
x = 0:5:400;
y = (beta_hat./rho_hat).*(x./rho_hat).^(beta_hat-1).*exp(-(x./rho_hat).^beta_hat);

figure()
plot(x,y)
xlabel('t [hours]','FontSize',16);ylabel('f(\tau_c)','FontSize',16);
t2 = text(200,0.0187,'$\hat{\rho}=48.3731$','Fontsize',14);
set(t2, 'Interpreter', 'latex','color','r')
t3 = text(200,0.0165,'$\hat{\beta}=0.7723$','Fontsize',14);
set(t3, 'Interpreter', 'latex','color','b')
grid on
% axis([1.32 1.42 0 45]);
width=15.875;
height=0.6*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','calms_pdf_moment.pdf')









