% this script determines parameters for monthly distributions of storms by
% using the method of moments. Area: Haltenbanken

clear

th = 2; % threshold value Hs'
years = years();
nr_of_years = 58;
tot_nr_of_obs = 0;
storms_months = zeros(1,12);
index = ones(1,12);
for i=1:nr_of_years
    for j = 1:12
        tmp_col = years(:,j,i);
        if isempty(tmp_col) == 1
        else
            tmp_col(tmp_col == 0)=[];
            tot_nr_of_obs = length(tmp_col); + tot_nr_of_obs;
            storms_in_month = durationz2(tmp_col,th);
            n_rows = length(storms_in_month(:,1));
            for k=1:n_rows
                tmp_row = storms_in_month(k,:);
                tmp_row(tmp_row==0)=[];
                nr_obs_in_row = length(tmp_row);
                nr_hours_in_storm = 3*nr_obs_in_row;
                storms_months(index(j),j) = nr_hours_in_storm;
                index(j) = index(j) + 1;
            end
        end
    end
end

% verification that all data is handled
if tot_nr_of_obs == 166053
    disp('All data has been handled')
end

% determining mean of each month
sum = zeros(1,12);
nr_storms = zeros(1,12);
for i = 1:12
    tmp_col = storms_months(:,i);
    tmp_col(tmp_col == 0) = [];
    nr_storms(1,i) = length(tmp_col);
    for j = 1:length(storms_months(:,i))
        sum(1,i) = sum(1,i) + storms_months(j,i);
    end
end
mean = sum./nr_storms;

% determining variance and skewness of each month
sum_var = zeros(1,12);
sum_skew = zeros(1,12);
variance2 = zeros(1,12);
for i = 1:12
    tmp_col = storms_months(:,i);
    tmp_col(tmp_col == 0) = [];
    variance2(i) = var(tmp_col);
    for j = 1:length(tmp_col)
        sum_var(i) = sum_var(i) + (tmp_col(j) - mean(i))^2 ;
        sum_skew(i) = sum_skew(i) + (tmp_col(j) - mean(i))^3 ;
     end
end

variance = sum_var./nr_storms;
standard_deviance = sqrt(variance);
skewness = (sum_skew./nr_storms)./(variance.^(3/2));

ratio = standard_deviance./mean;

beta = 0.3:0.00001:2;
nominator = zeros(length(beta),1);
denominator = zeros(length(beta),1);
c = zeros(1,12); index = zeros(1,12);
a = zeros(length(beta),12); beta_hat=zeros(1,12);
for i = 1:12
    for j = 1:length(beta)
        nominator(j) = sqrt( gamma(1 + (2/beta(j))) - (gamma(1 + (1/beta(j))))^2 );
        denominator(j) = gamma(1 + (1/beta(j)));
        a(j,i) = (nominator(j)/denominator(j)) - ratio(i);
    end
    [c(i), index(i)] = min(abs(a(:,i)-0));
    beta_hat(i) = beta(index(i));
end

rho_hat = mean./(gamma(1+ (1./beta_hat)));

% some figures and calculations follow

% probability paper for one of the months, July
% creating a diagram for various data:
storms_july = storms_months(:,7);
storms_july(storms_july == 0) = [];
n=length(storms_july);
dia=zeros(n,4);
dia(:,1)=sort(storms_july); % assigning tau_c values to column nr. 1 and sorting them
dia(:,2)=log(dia(:,1)); % taking log to tau_c values, column 2
dia(:,3)=(1:n)./(n+1); % cumulative distribution of tau_c, F_tau_c, column 3
dia(:,4)=log(-log(1-dia(:,3))); % F_tau_c on a Weibull scale, column 4

% removing repeating values
k=1;
for i=2:n
    if dia(i,1) == dia(i-1,1) 
        rm(k)=i-1; % an array which tells us which values we are to exclude
        k=k+1;
    end
end
dia(rm,:)=[]; % removing repeating values

CDF_july = 1 - exp(-((dia(:,1))./rho_hat(7)).^beta_hat(7));
y2 = log(-log(1-CDF_july));

% plotting cumulative distribution, from both data and estimated par.
figure()
plot(dia(:,1),dia(:,3),'.k',dia(:,1),CDF_july,'-r')
xlabel('\tau_s','Fontsize',18);ylabel('F_{\tau_s}','Fontsize',18);
width=15.875;
height=0.7*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','CDF_storm_july.pdf')

% probability paper
figure()
plot(dia(:,2),dia(:,4),'.k',dia(:,2),y2,'-r')
grid on
xlabel('ln(\tau_s)','Fontsize',18);ylabel('ln(-ln(1-F))','Fontsize',18);
% h_legend=legend('Observations','3 parameter Weibull fit','Location','northwest');
% set(h_legend,'FontSize',14);
width=15.875;
height=0.7*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','storms_july.pdf')



