% years.m, a function which sorts Hindcast data for Haltenbanken

function years = years()
    % fetching Hs, Tp and direction from the modified Hindcast
    % data file: Heidrun_WAM10_6529N_0732E.txt :
    fid = fopen('Heidrun_WAM10_6529N_0732E.txt','r');
    A = fscanf(fid,'%f %f %f %f %*f %*f %f %*f %*f %*f %*f %*f %*f %*f %*f %*f %*f',[5,inf])';
    fclose(fid);

    year = A(:,1);
    month = A(:,2);
    hs = A(:,5);

    nr_obs = length(hs);

    % data is sorted by year into 3D arrays. Each array represents one 
    % unique year. There are 12 columns in each year, each column is one 
    % unique month
    nr_of_years = length(min(year):1:max(year));
    years = zeros(250,12,nr_of_years);

    j=1;
    for i = 1:nr_obs
        if i==1
            years(j,month(i),(year(i)-1956)) = hs(i);
            if month(i)==month(i+1)
                j=j+1;
            else
                j=1;
            end
        elseif year(i) == year(i-1)
            years(j,month(i),(year(i)-1956)) = hs(i);
            if i==nr_obs
            elseif month(i)==month(i+1)
                j=j+1;
            else
                j=1;
            end
        elseif year(i) ~= year(i-1)
            years(j,month(i),(year(i)-1956)) = hs(i);
            if i==nr_obs
            elseif month(i)==month(i+1)
                j=j+1;
            else
                j=1;
            end
        end
    end

    % verification that all data is handled
    sum_data = 0;
    row_length = length(years(:,1,1));
    for p = 1:nr_of_years
        for q = 1:12
            for r = 1:row_length
                if years(r,q,p) == 0
                else
                    sum_data = sum_data + 1;
                end
            end
        end
    end

    if sum_data == nr_obs
        disp('All data has been handled')
    end

end