% CONTOUR LINES for HALTENBANKEN

global Hs_Tp_ok q_01 beta rho alpha theta eta q_ULS coeff_mu coeff_var

p=[1-q_01/2920, 1-q_ULS/2920];
r=norminv(p,0,1); % determining radius corresponding to values of q
n=1001;
dcircle=2*pi/(n-1);

for j=1:length(p)
    for i=1:n
        circle=dcircle*(i-1);
        U_1(i)=r(j)*cos(circle);
        U_2(i)=r(j)*sin(circle);
        Hs(i,j)=rho*(-log(1-normcdf(U_1(i)))).^(1/beta); %
        
        if Hs(i)>=eta
            contour_Hs(i,j)=Hs(i,j);
        else
            contour_Hs(i,j)=exp(theta+alpha*U_1(i));
        end
        
        mu(i,j)=coeff_mu(1)+coeff_mu(2)*contour_Hs(i,j)^coeff_mu(3);
        sigma(i,j)=coeff_var(1)+coeff_var(2)*exp(-coeff_var(3)*contour_Hs(i,j));
        contour_Tp(i,j)=exp(sqrt(sigma(i,j))*U_2(i)+mu(i,j));
    end
end

% contour plot
figure();
grid on
axis([4.9 30 1.9 18])
plot(contour_Tp(:,1),contour_Hs(:,1),'-r',Hs_Tp_ok(:,2),Hs_Tp_ok(:,1),'.b');
% set(gca,'FontSize',14)
h=legend('10 year contour plot','Acceptable H_s and T_p','FontSize',15);
set(h,'FontSize',13)
% legend boxoff
xlabel('T_p [s]','FontSize',15);ylabel('H_s [m]','FontSize',15);
text(20.15,14.5,'$q = 0.1$','FontSize',15)
text(20.15,15.3,'$\eta_{{3a}_c} = 4$ m','FontSize',15)
grid on
axis([4.9 30 1.9 18])
width=15.875;
height=1.1*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','hs_tp_ok_contour.pdf')