% this script estimates the probability that the longest calm of a month is
% below a certain number of hours. In this manner it can give an estimate
% to whether a marine operation is feasible or not.

% The final result is found in the array 'table'


% Area under investigation is Haltenbanken

clc
clear
close all

% hs values are fetched by function years.m:
years = years();

% the average duration of a calm, given a threshold value Hs' is calculated
% by the function avg_dur_calm.m:
th = 1:0.5:3; % threshold values Hs'
averages = zeros(length(th),12);
for i = 1:length(th)    
    averages(i,:) = avg_dur_func(years,th(i));
end
% monthly distributions are calculated by the function monthly_lon_func.m
parameters = monthly_lon_func(years);
alpha = parameters(1,:);
theta = parameters(2,:);

% with this the expected number of calms N in each month given threshold 
% Hs' can be determined
nr_hrs_month = [744,672,744,720,744,720,744,744,720,744,720,744];
P_Hs = zeros(length(th),12); % prob. of being under Hs'
nr_hrs_below_Hs = zeros(length(th),12);
N = zeros(length(th),12);
for i = 1:12
    for j = 1:length(th)
        P_Hs(j,i) = logncdf(th(j),theta(i),alpha(i));
        nr_hrs_below_Hs(j,i) = nr_hrs_month(i)*P_Hs(j,i);
        N(j,i) = nr_hrs_below_Hs(j,i)/averages(j,i);
    end
end

% parameters of monthly calms are fetched by function 
% monthly_calms_func.m:
parameters2 = zeros(2,12,length(th));
for i = 1:length(th)
    parameters2(:,:,i) = monthly_calms_func(years,th(i));
end

% finally, values of P[\tau_c_max > t] are determined
hrs = 12:12:84;
table = zeros(length(hrs),12,length(th));
for i = 1:length(hrs)
    for j = 1:12
        for k = 1:length(th)
            rho = parameters2(1,j,k);
            beta = parameters2(2,j,k);
            table(i,j,k) = 1-((1 - exp(-(hrs(i)/rho)^beta))^N(k,j));
        end
    end
end

x=1:800;
F = (1-exp(-((x)./(94.621)).^0.8785)).^(4.9);

figure()
plot(x,F,'-k',[232 232],[0 F(232)],'-r');
grid on
% axis([4.9 30 1.9 18])
xlabel('\tau_c [hours]','FontSize',16);ylabel('F_{\tau_{c_{max}}}','FontSize',16);
% legend('F_{\tau_{c_{max}}}','E[\tau_{c,max}]','Location','northeast','FontSize',15);
h=legend('F_{\tau_{c_{max}}}','E[\tau_{c,max}]','Location','northwest');
set(h,'FontSize',14)
width=15.875;
height=0.8*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','F_tau_c_max.pdf')

% dlmwrite('1.txt',table(:,:,1),'precision','%.2f');
% dlmwrite('2.txt',table(:,:,2),'precision','%.2f');
% dlmwrite('3.txt',table(:,:,3),'precision','%.2f');
% dlmwrite('4.txt',table(:,:,4),'precision','%.2f');
% dlmwrite('5.txt',table(:,:,5),'precision','%.2f');





