function parameters = monthly_calms_func(years,th)
% this script determines parameters by MOM for monthly distributions of 
% calms. The chosen model is a 2 parameter Weibull disribution. Area under
% investigation is Haltenbanken

    nr_of_years = 58;
    tot_nr_of_obs = 0;
    calms_months = zeros(1,12);
    index = ones(1,12);
    for i=1:nr_of_years
        for j = 1:12
            tmp_col = years(:,j,i);
            if isempty(tmp_col) == 1
            else
                tmp_col(tmp_col == 0)=[];
                tot_nr_of_obs = length(tmp_col); + tot_nr_of_obs;
                calms_in_month = durationz(tmp_col,th);
                n_rows = length(calms_in_month(:,1));
                for k=1:n_rows
                    tmp_row = calms_in_month(k,:);
                    tmp_row(tmp_row==0)=[];
                    nr_obs_in_row = length(tmp_row);
                    nr_hours_in_calm = 3*nr_obs_in_row;
                    calms_months(index(j),j) = nr_hours_in_calm;
                    index(j) = index(j) + 1;
                end
            end
        end
    end

    % verification that all data is handled
    if tot_nr_of_obs == 166053
        disp('All data has been handled')
    end

    % determining mean of each month
    sum = zeros(1,12);
    nr_calms = zeros(1,12);
    for i = 1:12
        tmp_col = calms_months(:,i);
        tmp_col(tmp_col == 0) = [];
        nr_calms(1,i) = length(tmp_col);
        for j = 1:length(calms_months(:,i))
            sum(1,i) = sum(1,i) + calms_months(j,i);
        end
    end
    mean = sum./nr_calms;

    % determining variance and skewness of each month
    sum_var = zeros(1,12);
    sum_skew = zeros(1,12);
    variance2 = zeros(1,12);
    for i = 1:12
        tmp_col = calms_months(:,i);
        tmp_col(tmp_col == 0) = [];
        variance2(i) = var(tmp_col);
        for j = 1:length(tmp_col)
            sum_var(i) = sum_var(i) + (tmp_col(j) - mean(i))^2 ;
            sum_skew(i) = sum_skew(i) + (tmp_col(j) - mean(i))^3 ;
         end
    end

    variance = sum_var./nr_calms;
    standard_deviance = sqrt(variance);
    skewness = (sum_skew./nr_calms)./(variance.^(3/2));

    ratio = standard_deviance./mean;

    beta = 0.3:0.00001:2;
    nominator = zeros(length(beta),1);
    denominator = zeros(length(beta),1);
    c = zeros(1,12); index = zeros(1,12);
    a = zeros(length(beta),12); beta_hat=zeros(1,12);
    for i = 1:12
        for j = 1:length(beta)
            nominator(j) = sqrt( gamma(1 + (2/beta(j))) - (gamma(1 + (1/beta(j))))^2 );
            denominator(j) = gamma(1 + (1/beta(j)));
            a(j,i) = (nominator(j)/denominator(j)) - ratio(i);
        end
        [c(i), index(i)] = min(abs(a(:,i)-0));
        beta_hat(i) = beta(index(i));
    end

    % estimator for parameter rho, rho_hat:
    rho_hat = mean./(gamma(1+ (1./beta_hat)));
    
    parameters = zeros(1,12);
    parameters(1,:) = rho_hat;
    parameters(2,:) = beta_hat;
end

