function parameters = monthly_lon_func(years)
% monthly lonowe distributions, haltenbanken

    nr_of_years = 58;
    months = zeros(1,12);
    % sorting all data into 12 months
    for i = 1:nr_of_years
        for l = 1:12
            for k = 1:250
                tmp_col = months(:,l);
                tmp_col(tmp_col == 0) = [];
                length_col = length(tmp_col);
                start = length_col + 1;
                if years(k,l,i) == 0
                else
                    months(start,l) = years(k,l,i);
                    start = start + 1;
                end
            end
        end
    end

    % verification that all data is handled
    nr_equal_or_over_16 = 0;
    sum_data = 0;
    for i = 1:12
        for l = 1:length(months)
            if months(l,i) == 0
            else
                sum_data = sum_data + 1;
            end
        end
    end
    if sum_data == 166053
        disp('All data has been handled')
    end

    theta_hat = zeros(1,12); alpha_hat = zeros(1,12); rho_hat = zeros(1,12);
    beta_hat=zeros(1,12); eta_hat = zeros(1,12);

    for i = 1:12
        tmp_col = months(:,i);
        tmp_col(tmp_col == 0) = [];
        n=length(tmp_col);

        % creating a diagram for various data:
        dia=zeros(n,5);
        dia(:,1)=sort(tmp_col); % assigning hs-values to column nr. 1 and sorting them
        dia(:,2)=log(dia(:,1)); % taking log to hs values, column 2
        dia(:,3)=(1:n)./(n+1); % cumulative distribution of Hs, F_Hs, column 3
        dia(:,4)=log(-log(1-dia(:,3))); % F_Hs on a Weibull scale, column 4
        dia(:,5)=erfinv((2*dia(:,3))-1); % F_Hs on a lognormal scale, column 5

        % removing repeating values
        rm = 0;
        k=1;
        for j=2:n
            if dia(j,1) == dia(j-1,1) 
                rm(k)=j-1; % an array which tells us which values we are to exclude
                k=k+1;
            end
        end
        dia(rm,:)=[]; % removing repeating values

        % ESTIMATING CUT-OFF VALUE ETA
        % estimating lognormal paramters using maximum likelihood:
        theta_hat(i)=mean(log(tmp_col));
        alpha_hat(i)=std(log(tmp_col));

        for l=1:100
            eta(l)=dia(1,1)+0.1*l; % starting value of eta, checking for all hs 
            rho(l)=0.3; % starting value of rho
            beta(l)=0.3; % starting value of beta
            % continuity in F and f at eta: 
            flog=exp(-(log(eta(l))-theta_hat(i)).^2/(2*alpha_hat(i)^2))./(eta(l)*sqrt(2*pi)*alpha_hat(i)); 
            Flog=1/2*(1+erf((log(eta(l))-theta_hat(i))/(alpha_hat(i)*sqrt(2))));
            % determining Weibull paramaters rho and beta via lognormal(continuity)
            for k=1:50;
                rho(l)=eta(l)/(-log(1-Flog))^(1/beta(l)); 
                beta(l)=flog/(1/rho(l)*(eta(l)/rho(l)).^(beta(l)-1).*exp(-(eta(l)/rho(l)).^beta(l)));
            end
            error_est(l)=0;
            for o=1:length(dia(:,1))
                if (dia(o,2))<log(eta(l))
                    error=((dia(o,2)-theta_hat(i))/(sqrt(2)*alpha_hat(i))-dia(o,5))^2;
                else
                    error=((beta(l)*dia(o,2)-beta(l)*log(rho(l)))-dia(o,4))^2; 
                end
                error_est(l)=error_est(l)+ error;
            end
        end    

        [~, s]=min(error_est); % determining which error is smallest
        beta_hat(i)=beta(s); 
        rho_hat(i)=rho(s); 
        eta_hat(i)=eta(s);
    end

    parameters = zeros(5,12);
    parameters(1,:) = alpha_hat;
    parameters(2,:) = theta_hat;
    parameters(3,:) = eta_hat;
    parameters(4,:) = rho_hat;
    parameters(5,:) = beta_hat;

end

