% this script runs the following scripts 
    % mar_op_weibull.m
        % This script simulates a marine operation by using the distribution of the duration of calms and storms.     
    % mar_op_hindcast.m
        % This script uses the hindcast data directly
% Both scripts simulates a marine operation consisting of 3 intervals x 24 hours,
% 2 breaks x 3 hours, and a constant threshold Hs'=2 metres.

clc
clear
close all

global table1 table2 op_durations1 op_durations2

run('mar_op_weibull.m') 
run('mar_op_hindcast.m') 

op_dur_wei = table1(1,:);   
op_dur_hind = table2(1,:);

x1 = 1:12;

figure() 
plot(x1,op_dur_wei,'-ro',x1,op_dur_hind,'-bo')
grid on
axis([0 13 0 550])
xlabel('Months','Fontsize',15);ylabel('Average duration of operation [hours]','Fontsize',15);
h_legend=legend('Using Weibull distributions','Using Hindcast data','Location','north');
set(h_legend,'FontSize',14);
% text(4000,850,'January','FontSize',16)
width=15.875;
height=0.6*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','op_durations_both')

x2 = 1:length(op_durations1{1});

figure() 
plot(x2,op_durations1{1},'.k')
grid on
axis([0 max(x2) 0 max(op_durations1{1})+150])
xlabel('Simulations','Fontsize',15);ylabel('Duration of Operation [hours]','Fontsize',15);
text(5800,850,'January','FontSize',16)
width=15.875;
height=0.6*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','op_durations_jan_10000.pdf')


x3 = 1:length(op_durations1{7});

figure() 
plot(x3,op_durations1{7},'.k')
grid on
axis([0 max(x3) 0 max(op_durations1{7})+20])
xlabel('Simulations','Fontsize',15);ylabel('Duration of Operation [hours]','Fontsize',15);
text(8200,400,'July','FontSize',16)
width=15.875;
height=0.6*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','op_durations_july_10000.pdf')

