% % ROLLING DUE TO SWELL SEA

% this script runs the following functions:        
    % spectrum.m                 % produces wave spectrum

% fetching hs,tp and direction on wind sea and swell
fid = fopen('wind_and_swell_sea_tp_mod.txt','r');
B = fscanf(fid,'%f %f %f %f %f %f',[6,inf])';
fclose(fid);

wind_sea_hs = B(:,1); wind_sea_tp = B(:,2); wind_sea_dir = B(:,3);
swell_hs = B(:,4); swell_tp = B(:,5); swell_dir = B(:,6);
n_obs = length(B);

count = 0;
for i = 1:n_obs
    if swell_dir(i) == wind_sea_dir(i)
        count = count + 1;
    end
end

% adjusted swell angle, assuming wind sea is zero degrees. In other words,
% swell_dir_adjusted gives the difference between swell sea and wind sea
swell_dir_adjusted = zeros(n_obs,1);
swell_dir_adjusted_deg = zeros(n_obs,1);
for i = 1:n_obs
    if swell_dir(i) > wind_sea_dir(i)
        swell_dir_adjusted(i) = swell_dir(i) - wind_sea_dir(i);
    elseif swell_dir(i) < wind_sea_dir(i)
        swell_dir_adjusted(i) = wind_sea_dir(i)-swell_dir(i);
    elseif swell_dir(i) == wind_sea_dir(i)
        swell_dir_adjusted(i) = 0;
    end
    
    % mirroring values due to symmetry 
    swell_dir_adjusted(i) = acosd(cosd(swell_dir_adjusted(i)));
end

% fetching RAO's from RAO.txt
fid = fopen('RAO.txt','r');
B = fscanf(fid,'%f %f',[2,inf])';
fclose(fid);

% sorting data
graph_nr = 0;
i = 1;
RAO = zeros(31,2,10);
while i <= length(B)
    if floor(B(i,1)) == 30;
        graph_nr = graph_nr + 1;
        j = 1;
    end
    
    RAO(j,1,graph_nr) = B(i,1);
    RAO(j,2,graph_nr) = B(i,2);
    
    j = j + 1;
    i = i + 1;
end

% interpolating
nr_curves = length(RAO(1,1,:));
step_size = 0.1;
RAO_int = cell(1,10); RAO_int_rad = cell(1,10);

k=1;l=2;m=1;n=2;
for i = 1:nr_curves
    
    x = fliplr(RAO(:,1,i)');
    y = fliplr(RAO(:,2,i)');
    
    % every point is multiplied by wave number k, in order to get the right
    % unit 
    k = zeros(1,length(x));
    for j = 1:length(y)
        k(j) = ((2*pi) / (1.561309992 * (x(j))^2 ));
        y(j) = y(j) * k(j);
    end
    
    min_x = min(x);
    max_x = max(x);
    x_new = (min_x:step_size:max_x);
    
    % using interpn function to interpolate
    y_new = interpn(x,y,x_new,'spline');

    xy = zeros(length(x_new),2);
    xy(:,1) = x_new;
    xy(:,2) = y_new;
    RAO_int{i} = xy;
    
    % changing from period (s) to circular freq. (rad/s):
    x_new_rad = x_new./(2*pi);
    xy_rad(:,1) = x_new_rad;
    xy_rad(:,2) = y_new;
    RAO_int_rad{i} = xy_rad;
    
end
angles = 30:30:150; % angles of RAO's


% plotting RAO's

figure() % RAO(T)
for i = 6:10
    xy = RAO_int{i};
    plot(xy(:,1),xy(:,2))
    xlabel('T [sec]');ylabel('\eta_{4A}/\lambda [rad/m]')
%     title('RAO, roll, with roll tank');
    hold on
end
grid on
Legend=cell(5,1);
for i=1:5
Legend{i}=strcat(num2str(angles(i)),'^{\circ}');
end
legend(Legend,'Fontsize',13)
width=15.875;
height=0.7*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','RAO_with_roll_tank.pdf')

figure() % RAO(w)
for i = 6:10
    xy = RAO_int_rad{i};
    plot(xy(:,1),xy(:,2))
    xlabel('\omega [rad/s]');ylabel('\eta_{4A}/\lambda [rad/m]')
    hold on
end
grid on
Legend=cell(5,1);
for i=1:5
Legend{i}=strcat(num2str(angles(i)),'^{\circ}');
end
legend(Legend,'Fontsize',13)
width=15.875;
height=0.7*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','RAO_with_roll_tank_radians.pdf')

    
% RAO's dependent on swell angle are chosen
RAO_dir = zeros(n_obs,1); values = zeros(length(angles),1);
for i = 1:n_obs
    if swell_dir_adjusted(i) <= 15
        RAO_dir(i) = 0;
    elseif swell_dir_adjusted(i) > 15 && swell_dir_adjusted(i) <= 45
        RAO_dir(i) = 30;
    elseif swell_dir_adjusted(i) > 45 && swell_dir_adjusted(i) <= 75
        RAO_dir(i) = 60;        
    elseif swell_dir_adjusted(i) > 75 && swell_dir_adjusted(i) <= 105
        RAO_dir(i) = 90;
    elseif swell_dir_adjusted(i) > 105 && swell_dir_adjusted(i) <= 135
        RAO_dir(i) = 120;
    elseif swell_dir_adjusted(i) > 135 && swell_dir_adjusted(i) <= 165
        RAO_dir(i) = 150;
    elseif swell_dir_adjusted(i) > 165 && swell_dir_adjusted(i) <= 180
        RAO_dir(i) = 0;
    end
end

% WITH roll tank
S = zeros(length(xy),n_obs);
Sn4 = zeros(length(xy),n_obs);
sigma_n4 = zeros(n_obs,1);
m0 = zeros(n_obs,1);
m2 = zeros(n_obs,1);
tm02 = zeros(n_obs,1);
N = zeros(n_obs,1);

for i = 1:n_obs
    if RAO_dir(i) == 0
        omega = 0; % no roll
        RAO_calc = 0; % no roll
    elseif RAO_dir(i) == 30
        xy = RAO_int_rad{6}; 
        omega = xy(:,1);
        RAO_calc = xy(:,2);
    elseif RAO_dir(i) == 60
        xy = RAO_int_rad{7}; 
        omega = xy(:,1);
        RAO_calc = xy(:,2);
    elseif RAO_dir(i) == 90
        xy = RAO_int_rad{8}; 
        omega = xy(:,1);
        RAO_calc = xy(:,2);
    elseif RAO_dir(i) == 120
        xy = RAO_int_rad{9}; 
        omega = xy(:,1);
        RAO_calc = xy(:,2);
    elseif RAO_dir(i) == 150
        xy = RAO_int_rad{10}; 
        omega = xy(:,1);
        RAO_calc = xy(:,2);
    end
        
    if omega == 0
        S(:,i) = 0; % no roll, no wave spectrum
    else
        S(:,i) = spectrum(swell_hs(i),swell_tp(i),omega);
    end
        
    if RAO_calc == 0
        Sn4(:,i) = 0; % no roll, no response spectrum
    else
        Sn4(:,i) = (RAO_calc.^2) .* S(:,i); % response spectrum
        sigma_n4(i) = sqrt(trapz(omega,Sn4(:,i))); % standard deviation
        m0(i) = sigma_n4(i); % 0th moment
        m2(i) = trapz(omega,((omega.^2).*Sn4(:,i))); % 1st moment
        tm02(i) = (2*pi) * sqrt(m0(i)/m2(i)); % zero crossing response period
        N(i) = 10800/tm02(i); % Number of zero crossing cycles
    end
end

figure()
histogram(swell_dir_adjusted)
xlabel('Adjusted swell angle [deg]','FontSize',15)
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','swell_dir.pdf')

figure()
histogram(swell_tp,20)
xlabel('Swell sea T_p [s]','FontSize',15)
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','swell_tp.pdf')

figure()
histogram(swell_hs,20)
xlabel('Swell sea H_s [m]','FontSize',15)
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','swell_hs.pdf')

figure()
histogram(sigma_n4,20)
xlabel('\sigma_{\eta_4} [rad]','FontSize',15)
axis([0 0.18 0 90000])
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','sigma_roll.pdf')

figure() 
plot(swell_dir_adjusted,sigma_n4,'.k')
xlabel('Adjusted swell direction [deg]','FontSize',15);ylabel('\sigma_{\eta_4} [rad]','FontSize',15);
axis([20 160 0 0.2])
labels = 0:15:180;
set(gca, 'XTick', labels); 
grid on
width=15.875;
height=0.7*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','large_sigma_swell_dir.pdf')

xy = RAO_int_rad{2}; 
omega = xy(:,1);
RAO_calc = xy(:,2);
RAO_plot = RAO_calc.^2;


% determining which values correspond to 30 degrees
indices = RAO_dir == 30;
sigma_n4_30 = sigma_n4(indices);
sigma_n4_30(isnan(sigma_n4_30)) = [];
mean_sigma_n4_30 = mean(sigma_n4_30);
max_sigma_n4_30 = max(sigma_n4_30);

% determining which values correspond to 60 degrees
indices = RAO_dir == 60;
sigma_n4_60 = sigma_n4(indices);
sigma_n4_60(isnan(sigma_n4_60)) = [];
mean_sigma_n4_60 = mean(sigma_n4_60);
max_sigma_n4_60 = max(sigma_n4_60);

% determining which values correspond to 90 degrees
indices = RAO_dir == 90;
sigma_n4_90 = sigma_n4(indices);
sigma_n4_90(isnan(sigma_n4_90)) = [];
mean_sigma_n4_90 = mean(sigma_n4_90);
% max_sigma_n4_90 = max(sigma_n4_90);

% average sigma, all angles
sigma_n4(isnan(sigma_n4)) =[];
sigma_n4(sigma_n4 == 0) = [];
mean_sigma_n4 = mean(sigma_n4);
max_sigma_n4 = max(sigma_n4);













