% DETERMINING GOOD WEATHER WINDOWS; TAKING BOTH HS (TOTAL SEA) AND ROLL
% RESPONSE (DUE TO SWELL SEA) INTO ACCOUNT

% this script runs the following functions:
    % years_with_swell.m         % fetches hs, total sea and hs, swell sea           
    % spectrum.m                 % produces wave spectrum
    
          
th_hs = 2; % threshold value Hs'
th_deg = 4; th_rad = th_deg*(pi/180);
q = 0.1;

% fetching sorted hindcast data by using function years_with_swell.m
[years,nr_obs] = years_with_swell();
nr_of_years = 58;

% fetching RAO's from RAO.txt
fid = fopen('RAO.txt','r');
B = fscanf(fid,'%f %f',[2,inf])';
fclose(fid);

% sorting data
graph_nr = 0;
i = 1;
RAO = zeros(31,2,10);
while i <= length(B)
    if floor(B(i,1)) == 30;
        graph_nr = graph_nr + 1;
        j = 1;
    end
    RAO(j,1,graph_nr) = B(i,1);
    RAO(j,2,graph_nr) = B(i,2);
    j = j + 1;
    i = i + 1;
end

% interpolating
nr_curves = length(RAO(1,1,:));
step_size = 0.1;
RAO_int = cell(1,10); RAO_int_rad = cell(1,10);
for i = 1:nr_curves
    x = fliplr(RAO(:,1,i)'); y = fliplr(RAO(:,2,i)');
    % every point is multiplied by wave number k, in order to achieve the
    % right unit
    k = zeros(1,length(x));
    for j = 1:length(y)
        k(j) = ((2*pi) / (1.561309992 * (x(j))^2 ));
        y(j) = y(j) * k(j);
    end
    min_x = min(x); max_x = max(x);
    x_new = (min_x:step_size:max_x);
    % using interpn function to interpolate
    y_new = interpn(x,y,x_new,'spline');
    xy = zeros(length(x_new),2);
    xy(:,1) = x_new; xy(:,2) = y_new;
    RAO_int{i} = xy;
    % changing from period (s) to circular freq. (rad/s):
    x_new_rad = x_new./(2*pi);
    xy_rad(:,1) = x_new_rad;
    xy_rad(:,2) = y_new;
    RAO_int_rad{i} = xy_rad;
end

average_calm = zeros(1,12,58); average_storm = zeros(1,12,58);
nr_calm_hrs_months = zeros(1,12); nr_storm_hrs_months = zeros(1,12);
nr_calms_months = zeros(1,12); nr_storms_months = zeros(1,12);
tot_nr_of_calms = 0; tot_nr_of_hours = 0; hrs_calms_month = 0;
tot_nr_of_obs = 0; nr_years_per_month = zeros(1,12);
calms_months = cell(12,200); 
swell_dir_adjusted_all = zeros(nr_obs,1); p = 0;
sigma_n4_all = zeros(nr_obs,1); f = 0;
swell_tp_all = zeros(nr_obs,1); r = 0;
N_all = zeros(nr_obs,1); 
large_sigmas = zeros(nr_obs,8); v = 0;
N_part = zeros(nr_obs,5); e = 0;

monthly_hrs_calms = zeros(1,12);
monthly_nr_calms = zeros(1,12);
monthly_calms = cell(nr_of_years,12);
monthly_storms = cell(nr_of_years,12);

for i=1:nr_of_years
    for j=1:12
        first_calm = 1; first_storm = 1;
        last_value_was_calm = []; last_value_was_storm = [];
        k = 1; l = 1;
        
        table = years{i,j};
        
        if ~any(table) == 1
        else
            tmp_hs = table(:,1);
            tmp_wind_sea_dir = table(:,4);
            tmp_swell_hs = table(:,5);
            tmp_swell_tp = table(:,6);
            tmp_swell_dir = table(:,7);
            
            for b = 1:length(tmp_hs)
                if ~any(tmp_hs(b)) == 1
                else
                    tot_nr_of_obs = tot_nr_of_obs + 1;
                end
            end
    calms = zeros(length(tmp_hs),1); storms = zeros(length(tmp_hs),1); 
    swell_dir_adjusted = zeros(length(tmp_hs),1);
    RAO_dir = zeros(length(tmp_hs),1);
    S = zeros(length(xy),length(tmp_hs)); % wave spectrums
    Sn4 = zeros(length(xy),length(tmp_hs)); % response spectrums
    sigma_n4 = zeros(length(tmp_hs),1); % stand. dev. response
    m0 = zeros(length(tmp_hs),1); % 0th moment of Sn4
    m2 = zeros(length(tmp_hs),1); % 2nd moment of Sn4
    tm02 = zeros(length(tmp_hs),1); % up crossing response period
    N = zeros(length(tmp_hs),1); % number of cycles
    prob = zeros(length(tmp_hs),1);

for m = 1:length(tmp_hs)
    if tmp_hs(m) == 0
    else
        % swell dir in terms of wind dir is determined
        if tmp_swell_dir(m) > tmp_wind_sea_dir(m)
            swell_dir_adjusted(m)=tmp_swell_dir(m)-tmp_wind_sea_dir(m);
        elseif tmp_swell_dir(m)<tmp_wind_sea_dir(m)
            swell_dir_adjusted(m)=tmp_wind_sea_dir(m)-tmp_swell_dir(m);
        elseif tmp_swell_dir(m) == tmp_wind_sea_dir(m)
            swell_dir_adjusted(m) = 0;
        end
        % mirroring angle due to symmetry 
        swell_dir_adjusted(m) = acosd(cosd(swell_dir_adjusted(m)));
        p = p+1; swell_dir_adjusted_all(p) = swell_dir_adjusted(m);
        % determining which RAO to use
        if swell_dir_adjusted(m) <= 15
            RAO_dir(m) = 0;
        elseif swell_dir_adjusted(m)>15 && swell_dir_adjusted(m)<=45
            RAO_dir(m) = 30;
        elseif swell_dir_adjusted(m)>45 && swell_dir_adjusted(m)<=75
            RAO_dir(m) = 60;        
        elseif swell_dir_adjusted(m)>75 && swell_dir_adjusted(m)<=105
            RAO_dir(m) = 90;
        elseif swell_dir_adjusted(m)>105 && swell_dir_adjusted(m)<=135
            RAO_dir(m) = 120;
        elseif swell_dir_adjusted(m)>135 && swell_dir_adjusted(m)<=165
            RAO_dir(m) = 150;
        elseif swell_dir_adjusted(m)>165 && swell_dir_adjusted(m)<=180
            RAO_dir(m) = 0;
        end

        if RAO_dir(m) == 0
            RAO_calc = zeros(261,1); % no roll
        elseif RAO_dir(m) == 30
            xy = RAO_int_rad{6}; 
            omega = xy(:,1);
            RAO_calc = xy(:,2);
        elseif RAO_dir(m) == 60
            xy = RAO_int_rad{7}; 
            omega = xy(:,1);
            RAO_calc = xy(:,2);
        elseif RAO_dir(m) == 90
            xy = RAO_int_rad{8}; 
            omega = xy(:,1);
            RAO_calc = xy(:,2);
        elseif RAO_dir(m) == 120
            xy = RAO_int_rad{9}; 
            omega = xy(:,1);
            RAO_calc = xy(:,2);
        elseif RAO_dir(m) == 150
            xy = RAO_int_rad{10}; 
            omega = xy(:,1);
            RAO_calc = xy(:,2);
        end

        if ~any(RAO_calc(:,1)) == 1 || tmp_swell_tp(m) == 0
            S(:,m) = 0; 
            Sn4(:,m) = 0;
            sigma_n4(m) = 0;
        else
            S(:,m) = spectrum(tmp_swell_hs(m),tmp_swell_tp(m),omega);
            Sn4(:,m) = (RAO_calc.^2) .* S(:,m); % 
            sigma_n4(m) = sqrt(trapz(omega,Sn4(:,m))); 
            m0(m) = sigma_n4(m); 
            m2(m) = trapz(omega,((omega.^2).*Sn4(:,m))); % 
            tm02(m) = (2*pi) * sqrt(m0(m)/m2(m)); 
            N(m) = 10800/tm02(m); 
        end

        f = f + 1; sigma_n4_all(f) = sigma_n4(m);
            
        r = r+1; swell_tp_all(r) = tmp_swell_tp(m);
        N_all(f) = N(m);

        if sigma_n4(m) == 0 % only Hs is considered
            if tmp_hs(m) <= th_hs 
                if first_calm == 1
                    calms(k) = calms(k) + 3;
                    first_calm = 0;
                else
                    if last_value_was_calm == 1
                        calms(k) = calms(k) + 3;
                    else
                        k = k+1; % new calm begins
                        calms(k) = calms(k) + 3;
                    end
                end
                last_value_was_calm = 1;
                last_value_was_storm = 0;
            else
                if first_storm == 1
                    storms(l) = storms(l) + 3;
                    first_storm = 0;
                else 
                    if last_value_was_storm == 1
                        storms(l) = storms(l) + 3;
                    else
                        l = l+1; % new storm begins
                        storms(l) = storms(l) + 3;
                    end
                end
                last_value_was_calm = 0;
                last_value_was_storm = 1;  
            end 
        else   

        prob(m) = (th_rad / sqrt(-2*log(1-(1-q)^(1/N(m)))));
        
        if sigma_n4(m) > prob(m)
            v = v + 1;
            large_sigmas(v,1) = sigma_n4(m);
            large_sigmas(v,2) = tmp_wind_sea_dir(m);
            large_sigmas(v,3) = tmp_swell_dir(m);
            large_sigmas(v,4) = tmp_swell_hs(m);
            large_sigmas(v,5) = tmp_swell_tp(m);
            large_sigmas(v,6) = swell_dir_adjusted(m);
            large_sigmas(v,7) = N(m);
            large_sigmas(v,8) = RAO_dir(m);
        end
        
        
        if sigma_n4(m) > prob(m) && sigma_n4(m) <= (4*(pi/180))
            e = e + 1;
            N_part(e,1) = N(m);
            N_part(e,2) = tmp_swell_hs(m);
            N_part(e,3) = tmp_swell_tp(m);
            N_part(e,4) = RAO_dir(m);
            N_part(e,5) = sigma_n4(m);
        end
            
            
            if tmp_hs(m) <= th_hs && sigma_n4(m) <= prob(m)
                % both Hs and n4 is considered
                if first_calm == 1
                    calms(k) = calms(k) + 3;
                    first_calm = 0;
                else
                    if last_value_was_calm == 1
                        calms(k) = calms(k) + 3;
                    else
                        k = k+1; % new calm begins
                        calms(k) = calms(k) + 3;
                    end
                end
                last_value_was_calm = 1;
                last_value_was_storm = 0;
            else
                if first_storm == 1
                    storms(l) = storms(l) + 3;
                    first_storm = 0;
                else 
                    if last_value_was_storm == 1
                        storms(l) = storms(l) + 3;
                    else
                        l = l+1; % new storm begins
                        storms(l) = storms(l) + 3;
                    end
                end
                last_value_was_calm = 0;
                last_value_was_storm = 1;    
            end

            if isempty(last_value_was_storm) == 1;
                last_value_was_storm = 0;
            end

            if isempty(last_value_was_calm) == 1;
                last_value_was_calm = 0;
            end
        end
    end
end
    calms(calms == 0) = [];  nr_calms = length(calms);
    monthly_hrs_calms(j) = monthly_hrs_calms(j) + sum(calms);
    monthly_nr_calms(j) = monthly_nr_calms(j) + nr_calms;
    monthly_calms{i,j} = calms;
    monthly_storms{i,j} = storms;
        end
    end
end

if tot_nr_of_obs ~= nr_obs
    disp('Missing data')
else
    disp('Every entry in Hindcast data has been evaluated')
end

monthly_average_calm = monthly_hrs_calms./monthly_nr_calms;

wb_calms = zeros(nr_of_years,12);
for i = 1:nr_of_years
    for j = 1:12
        tab = monthly_calms{i,j};
        if isempty(tab) == 1
            wb_calms(i,j) = 0;
        else
            nr_hrs = sum(tab(:,1));
            nr_calms = length(tab(:,1));
            wb_calms(i,j) = nr_hrs/nr_calms;
        end
    end
end

best_months = zeros(1,12); worst_months = zeros(1,12);
for i = 1:12
    tmp_col = wb_calms(:,i);
    tmp_col(tmp_col ==0) = [];
    best_months(i) = max(tmp_col);
    worst_months(i) = min(tmp_col);
end


% large_sigmas(large_sigmas == 0) = [];
[~,ix] = max(large_sigmas(:,1));
largest_sigma = large_sigmas(ix,1);
angle_attack = large_sigmas(:,5); angle_attack(angle_attack ==0)=[];
mf_angle_of_attack = mode(angle_attack);  %swell dir adjusted

% wind dir
wind_dir_1 = large_sigmas(:,2); wind_dir_1(wind_dir_1==0)=[];
nr_obz = length(wind_dir_1);
mf_wind_dir = mode(wind_dir_1); 
nr_mf_wind_dir = eq(wind_dir_1,mf_wind_dir);
nr_mf_wind_dir(nr_mf_wind_dir ==0)=[];
nr_mf_wind_dir = length(nr_mf_wind_dir);
perc_wind_dir = nr_mf_wind_dir/nr_obz;

indices1 = find(wind_dir_1 == mf_wind_dir);

% swell dir 
swell_dir1 = large_sigmas(:,3); swell_dir1(swell_dir1 == 0) = [];
mf_swell_dir = mode(swell_dir1);
ind = find(swell_dir1 == mf_swell_dir);
nr_mf_swell_dir = length(swell_dir1(ind));

swell_dir_given_wind_dir = swell_dir1(indices1); 
mf_swell_dir_given_wind_dir = mode(swell_dir_given_wind_dir);
indices2 = find(swell_dir_given_wind_dir == mf_swell_dir_given_wind_dir);


sigmas_larger_than_4_deg = zeros(nr_obz,1);
sigmas_smaller_than_4_deg = zeros(nr_obz,1);
N_larger_than = zeros(nr_obz,1); N_smaller_than = zeros(nr_obz,1);
for i = 1:length(large_sigmas(:,1))
    if large_sigmas(i,1) > (4*(pi/180))
        sigmas_larger_than_4_deg(i) = large_sigmas(i,1);
        N_larger_than(i) = large_sigmas(i,7);
    end
    
    if large_sigmas(i,1) <= (4*(pi/180))
        sigmas_smaller_than_4_deg(i) = large_sigmas(i,1);
        N_smaller_than(i) = large_sigmas(i,7);
    end
end
sigmas_larger_than_4_deg(sigmas_larger_than_4_deg == 0) = [];
sigmas_smaller_than_4_deg(sigmas_smaller_than_4_deg == 0) = [];
nr_sigmas_l_4_deg = length(sigmas_larger_than_4_deg);
nr_sigmas_s_4_deg = length(sigmas_smaller_than_4_deg);
N_smaller_than(N_smaller_than ==0) = [];
min_N_smaller_than = min(N_smaller_than);
max_N_smaller_than = max(N_smaller_than);
mean_N_smaller_than = mean(N_smaller_than);

swell_dir_ad_3 = large_sigmas(:,6);
swell_dir_ad_3(swell_dir_ad_3 == 0) = [];

uniq_swell = unique(swell_dir_ad_3);
swell_dir_ad_3_table = zeros(length(uniq_swell),1);

swell_dir_ad_3_table(1,1) = length(find(swell_dir_ad_3 == uniq_swell(1)));
swell_dir_ad_3_table(2,1) = length(find(swell_dir_ad_3 == uniq_swell(2)));
swell_dir_ad_3_table(3,1) = length(find(swell_dir_ad_3 == uniq_swell(3)));
swell_dir_ad_3_table(4,1) = length(find(swell_dir_ad_3 == uniq_swell(4)));
swell_dir_ad_3_table(5,1) = length(find(swell_dir_ad_3 == uniq_swell(5)));
swell_dir_ad_3_table(6,1) = length(find(swell_dir_ad_3 == uniq_swell(6)));
swell_dir_ad_3_table(7,1) = length(find(swell_dir_ad_3 == uniq_swell(7)));
swell_dir_ad_3_table(8,1) = length(find(swell_dir_ad_3 == uniq_swell(8)));
swell_dir_ad_3_table(9,1) = length(find(swell_dir_ad_3 == uniq_swell(9)));

RAO_dir2 = large_sigmas(:,8); 
RAO_dir2(RAO_dir2 ==0)=[];
uniq_RAO = unique(RAO_dir2);
RAO_dir2_table = zeros(length(uniq_RAO),1);

RAO_dir2_table(1,1) = length(find(RAO_dir2 == uniq_RAO(1)));
RAO_dir2_table(2,1) = length(find(RAO_dir2 == uniq_RAO(2)));
RAO_dir2_table(3,1) = length(find(RAO_dir2 == uniq_RAO(3)));
RAO_dir2_table(4,1) = length(find(RAO_dir2 == uniq_RAO(4)));
RAO_dir2_table(5,1) = length(find(RAO_dir2 == uniq_RAO(5)));


figure()
RAO_dir_2 = large_sigmas(:,8);
plot(RAO_dir_2,large_sigmas(:,1),'.k')
grid on
axis([0 160 0 0.2])
xlabel('RAO','Fontsize',15);
ylabel('\sigma_{\eta_4}','Fontsize',15);
labels = unique(RAO_dir_2);
set(gca, 'XTick', labels); 
width=15.875;
height=0.6*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','large_sigma_RAO.pdf')

figure()
swell_dir_ad_2 = large_sigmas(:,6);
swell_dir_ad_2(swell_dir_ad_2 == 0) = [];
large_sigmaz = large_sigmas(:,1);
large_sigmaz(large_sigmaz == 0) = [];
plot(swell_dir_ad_2,large_sigmaz,'.k')
grid on
axis([0 160 0 0.2])
xlabel('Adjusted Swell Direction','Fontsize',15);
ylabel('\sigma_{\eta_4}','Fontsize',15);
labels = unique(swell_dir_ad_2);
set(gca, 'XTick', labels); 
width=15.875;
height=0.6*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','large_sigma_swell_dir.pdf')


% PLOTTING'
figure()
bar(monthly_average_calm);
grid on
xlabel('Months','Fontsize',14);ylabel('Average \tau_c [hours]','Fontsize',14);
text(11.1,32,'H_s^{''} = 2 m','Fontsize',12)
text(11.1,29,'\eta_{4_c} = 4 deg','Fontsize',12)
% legend('Haltenbanken');
width=15.875;
height=0.6*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','calm_hs_and_roll_2.pdf')

figure() 
x=1:12;
plot(x,worst_months,'sr',x,monthly_average_calm,'sb',x,best_months,'sg')
grid on
axis([0 13 0 200])
legend('Worst months','Average months','Best months','Location','Northwest','Fontsize',14)
xlabel('Months','Fontsize',14);ylabel('Average \tau_c [hours]','Fontsize',14);
text(10.2,170,'H_s^{''} = 2 m','Fontsize',12)
text(10.2,150,'\eta_{4_c} = 4 deg','Fontsize',12)
width=15.875;
height=0.6*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','wmb_calm_hs_and_roll_2.pdf')


figure()
a= [12.6132075471698 24.5301204819277;12.7885714285714 28.5189873417722;16.0714285714286 33.7087378640777;19.4138851802403 44.0046728971963; 27.9123006833713 72.3777239709443; 32.6982035928144 91.5171428571429; 34.3691037735849 110.022580645161; 34.4132841328413 99.8571428571429; 21.5294117647059 52.9746835443038; 15.9593908629442 37.1101694915254;14.6882217090069 30.2483443708609; 12.7406250000000 25.5500000000000];
bar(a);
axis([0 14 0 140])
xlabel('Months','Fontsize',15);ylabel('Average \tau_c [hours]','Fontsize',15);
h=legend('Average \tau_c, roll considered','Average \tau_c, roll not considered');
set(h,'FontSize',14)
text(0.3,120,'H_s^{''} = 2 m','Fontsize',14)
text(0.3,110,'\eta_{4_{ac}} = 4 deg','Fontsize',14)
text(0.3,100,'q = 0.1','Fontsize',14)
grid on
width=15.875;
height=1.1*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','av_calm_both.pdf')

figure()
swell_tp2 = large_sigmas(:,5);
swell_tp2(swell_tp2 == 0) = [];
large_sigmaz = large_sigmas(:,1);
large_sigmaz(large_sigmaz == 0) = [];
plot(large_sigmaz,swell_tp2,'.k')
grid on
% axis([0 160 0 0.2])
ylabel('Swell T_p','Fontsize',15);
xlabel('\sigma_{\eta_4}','Fontsize',15);
% labels = unique(swell_tp2);
% set(gca, 'XTick', labels); 
width=15.875;
height=0.6*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
% print('-dpdf','-r500','large_sigma_swell_dir.pdf')

swell_hs_2 = large_sigmas(:,4);
swell_hs_2(swell_hs_2 == 0) = [];

mean_tp_swell_crit_sigma = mean(swell_tp2);
mean_wp_swell_crit_sigma = (2*pi)/mean_tp_swell_crit_sigma;
mean_hs_swell_crit_sigma = mean(swell_hs_2);
swell_wp2  = (2.*pi)./swell_tp2;
mean_swell_w = mean(swell_wp2);


nbins = 25;
figure()
histogram(swell_wp2,nbins)
xlabel('\omega_p, Swell sea (critical \sigma_{\eta_4}) [rad/s]','FontSize',14)
text(1.6,3500,'average \omega_p = 1.28 rad/s','FontSize',14)
width=15.875;
height=0.75*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','wp_swell_sea_large_sigma.pdf')

nbins = 25;
figure()
histogram(swell_hs_2,nbins)
xlabel('H_s, Swell sea (critical \sigma_{\eta_4}) [m]','FontSize',14)
text(6,6000,'average H_s = 2.38 m','FontSize',15)
width=15.875;
height=0.75*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','hs_swell_sea_large_sigma.pdf')


spectrum1 = spectrum(1,5,omega);
spectrum2 = spectrum(2,5,omega);

figure()
plot(omega,spectrum1,omega,spectrum2)
% axis([0 7 0 0.6])
xlabel('\omega [rad/s]','FontSize',15);ylabel('S(\omega) [m^2 s]','FontSize',15)
h = legend('H_s = 1 m, m_0 = 0.0610 m^2 rad','H_s = 2 m, m_0 = 0.2378 m^2 rad');
set(h,'FontSize',15)
text(3,0.35,'T_p = 3 s','FontSize',15)
width=15.875;
height=0.8*width;
set(gcf,'defaulttextinterpreter','latex',...
                'PaperUnits','centimeters','PaperSize',[width height],...
                'PaperPosition',[0,0,width,height],'Units','centimeters',...
                'Position',[1,10,width,height]);
print('-dpdf','-r500','spectrums.pdf')


